@@ -16,7 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -41,7 +41,11 @@ sub err {
 	# Die for eval.
 	} else {
 		my $e = $errors[-1]->{'msg'}->[0];
-		chomp $e;
+		if (! defined $e) {
+			$e = 'undef';
+		} else {
+			chomp $e;
+		}
 		die "$e\n";
 	}
 
@@ -190,6 +194,6 @@ BSD license.
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
